# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdCheckableTag(Component):
    """An AntdCheckableTag component.


Keyword arguments:

- id (string; optional)

- checked (boolean; default False):
    设置或监听当前标签的选择状态  默认：False.

- checkedContent (a list of or a singular dash component, string or number; optional)

- className (string | dict; optional)

- content (a list of or a singular dash component, string or number; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- style (dict; optional)

- unCheckedContent (a list of or a singular dash component, string or number; optional)"""
    _children_props = ['content', 'checkedContent', 'unCheckedContent']
    _base_nodes = ['content', 'checkedContent', 'unCheckedContent', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCheckableTag'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, content=Component.UNDEFINED, checkedContent=Component.UNDEFINED, unCheckedContent=Component.UNDEFINED, checked=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'checked', 'checkedContent', 'className', 'content', 'key', 'loading_state', 'style', 'unCheckedContent']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'checked', 'checkedContent', 'className', 'content', 'key', 'loading_state', 'style', 'unCheckedContent']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdCheckableTag, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdFloatButton(Component):
    """An AntdFloatButton component.


Keyword arguments:

- id (string; optional)

- className (string | dict; optional)

- description (a list of or a singular dash component, string or number; optional):
    组件型，用于设置文字及其他内容，仅shape='square'时可用.

- href (string; optional):
    为按钮设置点击后跳转的链接地址.

- icon (a list of or a singular dash component, string or number; optional):
    组件型，用于设置自定义图标元素.

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- nClicks (number; default 0):
    监听当前悬浮按钮累计点击次数.

- shape (a value equal to: 'circle', 'square'; default 'circle'):
    设置按钮形状，可选的有'circle'、'square'  默认：'circle'.

- style (dict; optional)

- target (string; default '_blank'):
    设置链接点击跳转行为  默认：'_blank'.

- tooltip (a list of or a singular dash component, string or number; optional):
    组件型，用于设置附加气泡卡片的内部元素.

- type (a value equal to: 'default', 'primary'; default 'default'):
    设置按钮类型，可选的有'default'、'primary'  默认：'default'."""
    _children_props = ['icon', 'description', 'tooltip']
    _base_nodes = ['icon', 'description', 'tooltip', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFloatButton'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, icon=Component.UNDEFINED, description=Component.UNDEFINED, tooltip=Component.UNDEFINED, type=Component.UNDEFINED, shape=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, nClicks=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'description', 'href', 'icon', 'key', 'loading_state', 'nClicks', 'shape', 'style', 'target', 'tooltip', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'description', 'href', 'icon', 'key', 'loading_state', 'nClicks', 'shape', 'style', 'target', 'tooltip', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdFloatButton, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdDropdown(Component):
    """An AntdDropdown component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    自定义下拉菜单锚定的自定义元素，优先级最高.

- id (string; optional)

- arrow (boolean; default False)

- autoAdjustOverflow (boolean; default True)

- batchPropsNames (list of strings; optional)

- batchPropsValues (dict; optional)

- buttonMode (boolean; default False)

- buttonProps (dict; optional)

    `buttonProps` is a dict with keys:

    - className (string; optional)

    - danger (boolean; optional)

    - size (a value equal to: 'default', 'small', 'large'; optional)

    - style (dict; optional)

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional)

- className (string | dict; optional)

- clickedKey (string; optional)

- disabled (boolean; default False)

- freePosition (boolean; default False)

- freePositionClassName (string; optional)

- freePositionStyle (dict; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- menuItems (list of dicts; optional)

    `menuItems` is a list of dicts with keys:

    - disabled (boolean; optional)

    - href (string; optional)

    - icon (string; optional)

    - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional)

    - isDivider (boolean; optional)

    - key (string; optional)

    - target (string; optional)

    - title (a list of or a singular dash component, string or number; optional)

- multiple (boolean; optional):
    设置菜单是否允许多选  默认：False.

- nClicks (number; default 0)

- nonSelectableKeys (list of strings; optional):
    设置不可选中项key值数组  默认：[].

- overlayClassName (string | dict; optional)

- overlayStyle (dict; optional)

- placement (a value equal to: 'bottomLeft', 'bottomCenter', 'bottomRight', 'topLeft', 'topCenter', 'topRight'; optional)

- popupContainer (a value equal to: 'parent', 'body'; default 'body')

- selectable (boolean; optional):
    设置菜单项是否可选中  默认：False.

- selectedKeys (list of strings; optional):
    设置或监听当前已选中菜单项key值数组.

- style (dict; optional)

- title (string; optional)

- trigger (a value equal to: 'click', 'hover'; default 'hover')

- visible (boolean; default False)

- wrapperClassName (string | dict; optional):
    针对自定义锚定元素的父容器设置css类名.

- wrapperStyle (dict; optional):
    针对自定义锚定元素的父容器设置css样式."""
    _children_props = ['menuItems[].title']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDropdown'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, wrapperStyle=Component.UNDEFINED, wrapperClassName=Component.UNDEFINED, key=Component.UNDEFINED, title=Component.UNDEFINED, buttonMode=Component.UNDEFINED, buttonProps=Component.UNDEFINED, freePosition=Component.UNDEFINED, freePositionStyle=Component.UNDEFINED, freePositionClassName=Component.UNDEFINED, clickedKey=Component.UNDEFINED, nClicks=Component.UNDEFINED, menuItems=Component.UNDEFINED, selectable=Component.UNDEFINED, multiple=Component.UNDEFINED, selectedKeys=Component.UNDEFINED, nonSelectableKeys=Component.UNDEFINED, arrow=Component.UNDEFINED, disabled=Component.UNDEFINED, overlayClassName=Component.UNDEFINED, overlayStyle=Component.UNDEFINED, placement=Component.UNDEFINED, trigger=Component.UNDEFINED, autoAdjustOverflow=Component.UNDEFINED, visible=Component.UNDEFINED, popupContainer=Component.UNDEFINED, batchPropsNames=Component.UNDEFINED, batchPropsValues=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'arrow', 'autoAdjustOverflow', 'batchPropsNames', 'batchPropsValues', 'buttonMode', 'buttonProps', 'className', 'clickedKey', 'disabled', 'freePosition', 'freePositionClassName', 'freePositionStyle', 'key', 'loading_state', 'menuItems', 'multiple', 'nClicks', 'nonSelectableKeys', 'overlayClassName', 'overlayStyle', 'placement', 'popupContainer', 'selectable', 'selectedKeys', 'style', 'title', 'trigger', 'visible', 'wrapperClassName', 'wrapperStyle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'arrow', 'autoAdjustOverflow', 'batchPropsNames', 'batchPropsValues', 'buttonMode', 'buttonProps', 'className', 'clickedKey', 'disabled', 'freePosition', 'freePositionClassName', 'freePositionStyle', 'key', 'loading_state', 'menuItems', 'multiple', 'nClicks', 'nonSelectableKeys', 'overlayClassName', 'overlayStyle', 'placement', 'popupContainer', 'selectable', 'selectedKeys', 'style', 'title', 'trigger', 'visible', 'wrapperClassName', 'wrapperStyle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDropdown, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdFloatButtonGroup(Component):
    """An AntdFloatButtonGroup component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    当前悬浮按钮组内各悬浮按钮组件.

- id (string; optional)

- className (string | dict; optional)

- description (a list of or a singular dash component, string or number; optional):
    组件型，用于设置文字及其他内容，仅shape='square'时可用.

- icon (a list of or a singular dash component, string or number; optional):
    组件型，用于设置自定义图标元素.

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- open (boolean; optional):
    用于设置或监听当前悬浮按钮组展开状态.

- shape (a value equal to: 'circle', 'square'; default 'circle'):
    设置内部各按钮形状，可选的有'circle'、'square'  默认：'circle'.

- style (dict; optional)

- tooltip (a list of or a singular dash component, string or number; optional):
    组件型，用于设置附加气泡卡片的内部元素.

- trigger (a value equal to: 'click', 'hover'; optional):
    当传入有效值时，用于设置菜单触发模式，可选的有'click'、'hover'.

- type (a value equal to: 'default', 'primary'; default 'default'):
    设置按钮类型，可选的有'default'、'primary'  默认：'default'."""
    _children_props = ['icon', 'description', 'tooltip']
    _base_nodes = ['icon', 'description', 'tooltip', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFloatButtonGroup'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, icon=Component.UNDEFINED, description=Component.UNDEFINED, tooltip=Component.UNDEFINED, type=Component.UNDEFINED, shape=Component.UNDEFINED, trigger=Component.UNDEFINED, open=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'description', 'icon', 'key', 'loading_state', 'open', 'shape', 'style', 'tooltip', 'trigger', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'description', 'icon', 'key', 'loading_state', 'open', 'shape', 'style', 'tooltip', 'trigger', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFloatButtonGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSider(Component):
    """An AntdSider component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the tab - will only be displayed if this tab is
    selected.

- id (string; optional)

- breakpoint (a value equal to: 'xs', 'sm', 'md', 'lg', 'xl', 'xxl'; optional)

- className (string | dict; optional)

- collapsed (boolean; default False)

- collapsedWidth (number; default 80)

- collapsible (boolean; default False)

- defaultCollapsed (boolean; default False)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- reverseArrow (boolean; default False)

- style (dict; optional)

- theme (a value equal to: 'light', 'dark'; default 'dark')

- trigger (a list of or a singular dash component, string or number; optional)

- width (number | string; default 200)"""
    _children_props = ['trigger']
    _base_nodes = ['trigger', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSider'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, collapsed=Component.UNDEFINED, defaultCollapsed=Component.UNDEFINED, collapsedWidth=Component.UNDEFINED, collapsible=Component.UNDEFINED, reverseArrow=Component.UNDEFINED, theme=Component.UNDEFINED, width=Component.UNDEFINED, trigger=Component.UNDEFINED, breakpoint=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'breakpoint', 'className', 'collapsed', 'collapsedWidth', 'collapsible', 'defaultCollapsed', 'key', 'loading_state', 'reverseArrow', 'style', 'theme', 'trigger', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'breakpoint', 'className', 'collapsed', 'collapsedWidth', 'collapsible', 'defaultCollapsed', 'key', 'loading_state', 'reverseArrow', 'style', 'theme', 'trigger', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSider, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdColorPicker(Component):
    """An AntdColorPicker component.


Keyword arguments:

- id (string; optional)

- allowClear (boolean; default False):
    是否允许清除已选颜色  默认：False.

- arrow (dict; optional):
    配置颜色选择面板附带的箭头  默认：True.

    `arrow` is a boolean | dict with keys:

    - pointAtCenter (boolean; optional):
        箭头是否位于面板中心.

- className (string | dict; optional)

- disabled (boolean; default False):
    是否禁用当前组件  默认：False.

- disabledAlpha (boolean; default True):
    是否禁用透明度选择  默认：True.

- format (a value equal to: 'rgb', 'hex', 'hsb'; default 'hex'):
    设置或监听当前的颜色格式，可选的有'rgb'、'hex'、'hsb'  默认：'hex'.

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- open (boolean; optional):
    设置或监听当前颜色选择面板展开状态.

- placement (a value equal to: 'top', 'topLeft', 'topRight', 'bottom', 'bottomLeft', 'bottomRight'; default 'bottomLeft'):
    设置颜色选择面板的展开方位，可选的有'top'、'topLeft'、'topRight'、'bottom'、'bottomLeft'、'bottomRight'
    默认：'bottomLeft'.

- presets (list of dicts; optional):
    配置预设颜色选择项列表.

    `presets` is a list of dicts with keys:

    - colors (list of strings; optional):
        当前项对应的预设色彩值数组.

    - defaultOpen (boolean; optional):
        当前项默认是否展开.

    - label (a list of or a singular dash component, string or number; optional):
        当前项的标签内容.

- showText (boolean; default False):
    是否显示颜色值文本  默认：False.

- size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
    设置触发器尺寸规格，可选的有'large'、'middle'、'small'  默认：'middle'.

- style (dict; optional)

- trigger (a value equal to: 'hover', 'click'; default 'click'):
    设置颜色选择面板触发方式，可选的有'hover'、'click'  默认：'click'.

- value (string; default '#1677FF'):
    设置或监听当前选中的颜色值  默认：'#1677FF'."""
    _children_props = ['presets[].label']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdColorPicker'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, allowClear=Component.UNDEFINED, arrow=Component.UNDEFINED, value=Component.UNDEFINED, format=Component.UNDEFINED, disabled=Component.UNDEFINED, disabledAlpha=Component.UNDEFINED, open=Component.UNDEFINED, presets=Component.UNDEFINED, placement=Component.UNDEFINED, showText=Component.UNDEFINED, size=Component.UNDEFINED, trigger=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowClear', 'arrow', 'className', 'disabled', 'disabledAlpha', 'format', 'key', 'loading_state', 'open', 'placement', 'presets', 'showText', 'size', 'style', 'trigger', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowClear', 'arrow', 'className', 'disabled', 'disabledAlpha', 'format', 'key', 'loading_state', 'open', 'placement', 'presets', 'showText', 'size', 'style', 'trigger', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdColorPicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTree(Component):
    """An AntdTree component.


Keyword arguments:

- id (string; optional)

- batchPropsNames (list of strings; optional)

- batchPropsValues (dict; optional)

- caseSensitive (boolean; default True)

- checkStrictly (boolean; default False)

- checkable (boolean; default False)

- checkedKeys (list of strings; optional)

- className (string | number; optional)

- clickedContextMenu (dict; optional)

    `clickedContextMenu` is a dict with keys:

    - menuKey (string; optional)

    - nodeKey (string; optional)

    - timestamp (number; optional)

- defaultCheckedKeys (list of strings; optional)

- defaultExpandAll (boolean; default False)

- defaultExpandParent (boolean; default False)

- defaultExpandedKeys (list of strings; optional)

- defaultSelectedKeys (list of strings; optional)

- dragInSameLevel (boolean; default False)

- draggable (boolean; default False)

- draggedNodeKey (string; optional)

- enableNodeFavorites (boolean; default False)

- expandedKeys (list of strings; optional)

- favoritedKeys (list of strings; optional)

- halfCheckedKeys (list of strings; optional)

- height (number; optional)

- highlightStyle (dict; default {
    fontWeight: 'bold',
    backgroundColor: 'transparent',
    padding: 0,
    color: '#ff5500'
})

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- multiple (boolean; default False)

- nodeCheckedStyle (dict; optional)

- nodeCheckedSuffix (a list of or a singular dash component, string or number; optional)

- nodeUncheckedStyle (dict; optional)

- nodeUncheckedSuffix (a list of or a singular dash component, string or number; optional)

- persisted_props (list of a value equal to: 'selectedKeys', 'checkedKeys', 'expandedKeys', 'halfCheckedKeys's; default ['selectedKeys', 'checkedKeys', 'expandedKeys', 'halfCheckedKeys']):
    Properties whose user interactions will persist after refreshing
    the  component or the page. Since only `value` is allowed this
    prop can  normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when  the component - or the page - is refreshed. If `persisted`
    is truthy and  hasn't changed from its previous value, a `value`
    that the user has  changed while using the app will keep that
    change, as long as  the new `value` also matches what was given
    originally.  Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored:  memory: only kept in
    memory, reset on page refresh.  local: window.localStorage, data
    is kept after the browser quit.  session: window.sessionStorage,
    data is cleared once the browser quit.

- scrollTarget (dict; optional)

    `scrollTarget` is a dict with keys:

    - align (a value equal to: 'top', 'bottom', 'auto'; optional)

    - key (string; required)

    - offset (number; optional)

- searchKeyword (string | list of strings; optional)

- selectable (boolean; default True)

- selectedKeys (list of strings; optional)

- showIcon (boolean; default False)

- showLine (dict; default { 'showLeafIcon': False })

    `showLine` is a boolean | dict with keys:

    - showLeafIcon (boolean; optional)

- style (dict; optional)

- treeData (list; optional)

- treeDataMode (a value equal to: 'tree', 'flat'; default 'tree')

- treeNodeKeyToTitle (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional)"""
    _children_props = ['treeNodeKeyToTitle{}', 'nodeCheckedSuffix', 'nodeUncheckedSuffix']
    _base_nodes = ['nodeCheckedSuffix', 'nodeUncheckedSuffix', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTree'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, treeDataMode=Component.UNDEFINED, treeData=Component.UNDEFINED, treeNodeKeyToTitle=Component.UNDEFINED, showIcon=Component.UNDEFINED, selectable=Component.UNDEFINED, multiple=Component.UNDEFINED, checkable=Component.UNDEFINED, defaultExpandAll=Component.UNDEFINED, expandedKeys=Component.UNDEFINED, defaultExpandedKeys=Component.UNDEFINED, defaultExpandParent=Component.UNDEFINED, selectedKeys=Component.UNDEFINED, defaultSelectedKeys=Component.UNDEFINED, checkedKeys=Component.UNDEFINED, defaultCheckedKeys=Component.UNDEFINED, halfCheckedKeys=Component.UNDEFINED, checkStrictly=Component.UNDEFINED, showLine=Component.UNDEFINED, height=Component.UNDEFINED, draggable=Component.UNDEFINED, dragInSameLevel=Component.UNDEFINED, draggedNodeKey=Component.UNDEFINED, clickedContextMenu=Component.UNDEFINED, enableNodeFavorites=Component.UNDEFINED, favoritedKeys=Component.UNDEFINED, scrollTarget=Component.UNDEFINED, searchKeyword=Component.UNDEFINED, caseSensitive=Component.UNDEFINED, highlightStyle=Component.UNDEFINED, nodeCheckedSuffix=Component.UNDEFINED, nodeUncheckedSuffix=Component.UNDEFINED, nodeCheckedStyle=Component.UNDEFINED, nodeUncheckedStyle=Component.UNDEFINED, batchPropsNames=Component.UNDEFINED, batchPropsValues=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'batchPropsNames', 'batchPropsValues', 'caseSensitive', 'checkStrictly', 'checkable', 'checkedKeys', 'className', 'clickedContextMenu', 'defaultCheckedKeys', 'defaultExpandAll', 'defaultExpandParent', 'defaultExpandedKeys', 'defaultSelectedKeys', 'dragInSameLevel', 'draggable', 'draggedNodeKey', 'enableNodeFavorites', 'expandedKeys', 'favoritedKeys', 'halfCheckedKeys', 'height', 'highlightStyle', 'key', 'loading_state', 'multiple', 'nodeCheckedStyle', 'nodeCheckedSuffix', 'nodeUncheckedStyle', 'nodeUncheckedSuffix', 'persisted_props', 'persistence', 'persistence_type', 'scrollTarget', 'searchKeyword', 'selectable', 'selectedKeys', 'showIcon', 'showLine', 'style', 'treeData', 'treeDataMode', 'treeNodeKeyToTitle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'batchPropsNames', 'batchPropsValues', 'caseSensitive', 'checkStrictly', 'checkable', 'checkedKeys', 'className', 'clickedContextMenu', 'defaultCheckedKeys', 'defaultExpandAll', 'defaultExpandParent', 'defaultExpandedKeys', 'defaultSelectedKeys', 'dragInSameLevel', 'draggable', 'draggedNodeKey', 'enableNodeFavorites', 'expandedKeys', 'favoritedKeys', 'halfCheckedKeys', 'height', 'highlightStyle', 'key', 'loading_state', 'multiple', 'nodeCheckedStyle', 'nodeCheckedSuffix', 'nodeUncheckedStyle', 'nodeUncheckedSuffix', 'persisted_props', 'persistence', 'persistence_type', 'scrollTarget', 'searchKeyword', 'selectable', 'selectedKeys', 'showIcon', 'showLine', 'style', 'treeData', 'treeDataMode', 'treeNodeKeyToTitle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTree, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdProgress(Component):
    """An AntdProgress component.


Keyword arguments:

- id (string; optional)

- className (string | dict; optional)

- format (dict; optional)

    `format` is a dict with keys:

    - content (a list of or a singular dash component, string or number; optional)

    - prefix (string; optional)

    - suffix (string; optional)

- gapDegree (number; optional)

- gapPosition (a value equal to: 'top', 'bottom', 'left', 'right'; default 'bottom')

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- percent (number; default 0)

- showInfo (boolean; default True)

- size (number | list of numbers | a value equal to: 'small', 'default'; default 'default')

- status (a value equal to: 'success', 'exception', 'normal', 'active'; optional)

- steps (number; optional)

- strokeColor (dict; optional)

    `strokeColor` is a string | dict with keys:

    - from (string; optional)

    - to (string; optional)

- strokeLinecap (a value equal to: 'round', 'butt', 'square'; optional)

- strokeWidth (number; optional)

- style (dict; optional)

- success (dict; optional)

    `success` is a dict with keys:

    - percent (number; optional)

    - strokeColor (dict; optional)

        `strokeColor` is a string

      Or dict with keys:

        - from (string; optional)

        - to (string; optional)

- trailColor (string; optional)

- type (a value equal to: 'line', 'circle', 'dashboard'; default 'line')

- width (number; default 132)"""
    _children_props = ['format.content']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdProgress'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, type=Component.UNDEFINED, size=Component.UNDEFINED, percent=Component.UNDEFINED, success=Component.UNDEFINED, format=Component.UNDEFINED, status=Component.UNDEFINED, showInfo=Component.UNDEFINED, strokeColor=Component.UNDEFINED, strokeLinecap=Component.UNDEFINED, strokeWidth=Component.UNDEFINED, trailColor=Component.UNDEFINED, width=Component.UNDEFINED, gapDegree=Component.UNDEFINED, gapPosition=Component.UNDEFINED, steps=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'format', 'gapDegree', 'gapPosition', 'key', 'loading_state', 'percent', 'showInfo', 'size', 'status', 'steps', 'strokeColor', 'strokeLinecap', 'strokeWidth', 'style', 'success', 'trailColor', 'type', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'format', 'gapDegree', 'gapPosition', 'key', 'loading_state', 'percent', 'showInfo', 'size', 'status', 'steps', 'strokeColor', 'strokeLinecap', 'strokeWidth', 'style', 'success', 'trailColor', 'type', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdProgress, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdButton(Component):
    """An AntdButton component.
按钮组件AntdButton，api参数参考https://ant.design/components/button-cn/

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    当前按钮内嵌元素.

- id (string; optional):
    当前组件唯一id.

- autoSpin (boolean; default False):
    当前按钮在每次点击后是否自动进入加载中状态  默认：False.

- block (boolean; default False):
    当前按钮是否撑满父元素  默认：False.

- className (string | dict; optional):
    当前按钮css类，支持动态css类特性.

- classNames (dict; optional):
    细分控制子元素css类.

    `classNames` is a dict with keys:

    - icon (string; optional):
        控制图标部分元素css类.

- clickExecuteJsString (string; optional):
    按钮点击时额外需要执行的js程序字符串.

- danger (boolean; default False):
    当前按钮是否呈现危险状态  默认：False.

- debounceWait (number; default 200):
    当前按钮点击事件监听防抖延时，单位：毫秒  默认：200.

- disabled (boolean; default False):
    当前按钮是否呈现禁用状态  默认：False.

- ghost (boolean; default False):
    幽灵属性，使当前按钮背景透明  默认：False.

- href (string; optional):
    当前按钮点击跳转链接地址.

- icon (a list of or a singular dash component, string or number; optional):
    当前按钮内嵌元素前缀图标.

- key (string; optional):
    当前组件辅助用唯一id，可通过更新key值实现强制重绘.

- loading (boolean; optional):
    当前按钮是否呈现加载中状态  默认：False.

- loadingChildren (a list of or a singular dash component, string or number; optional):
    当前按钮加载状态下内嵌元素.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- motionType (a value equal to: 'happy-work'; optional):
    为当前按钮设置特殊的点击动效，可选的有'happy-work'.

- nClicks (number; default 0):
    当前按钮累计被点击次数  默认：0.

- shape (a value equal to: 'default', 'circle', 'round'; default 'default'):
    当前按钮形状，可选的有'default'、'circle'、'round'  默认：'default'.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    当前按钮尺寸规格，可选的有'small'、'middle'、'large'  默认：'middle'.

- style (dict; optional):
    当前按钮css样式.

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - icon (dict; optional):
        控制图标部分元素css样式.

- target (string; optional):
    当前按钮点击跳转链接行为类型.

- type (a value equal to: 'default', 'primary', 'ghost', 'dashed', 'link', 'text'; default 'default'):
    当前按钮类型，可选的有'default'、'primary'、'ghost'、'dashed'、'link'、'text'
    默认：'primary'."""
    _children_props = ['loadingChildren', 'icon']
    _base_nodes = ['loadingChildren', 'icon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdButton'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, styles=Component.UNDEFINED, classNames=Component.UNDEFINED, key=Component.UNDEFINED, loadingChildren=Component.UNDEFINED, type=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, block=Component.UNDEFINED, danger=Component.UNDEFINED, disabled=Component.UNDEFINED, ghost=Component.UNDEFINED, shape=Component.UNDEFINED, size=Component.UNDEFINED, nClicks=Component.UNDEFINED, clickExecuteJsString=Component.UNDEFINED, debounceWait=Component.UNDEFINED, icon=Component.UNDEFINED, loading=Component.UNDEFINED, autoSpin=Component.UNDEFINED, motionType=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoSpin', 'block', 'className', 'classNames', 'clickExecuteJsString', 'danger', 'debounceWait', 'disabled', 'ghost', 'href', 'icon', 'key', 'loading', 'loadingChildren', 'loading_state', 'motionType', 'nClicks', 'shape', 'size', 'style', 'styles', 'target', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoSpin', 'block', 'className', 'classNames', 'clickExecuteJsString', 'danger', 'debounceWait', 'disabled', 'ghost', 'href', 'icon', 'key', 'loading', 'loadingChildren', 'loading_state', 'motionType', 'nClicks', 'shape', 'size', 'style', 'styles', 'target', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdButton, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdQRCode(Component):
    """An AntdQRCode component.


Keyword arguments:

- id (string; optional)

- autoSpin (boolean; default False):
    是否在value处于回调更新中时，自动切换到loading状态  默认：False.

- bgColor (string; default 'transparent'):
    设置二维码背景颜色  默认：'transparent'.

- bordered (boolean; default True):
    设置二维码是否有边框  默认：True.

- className (string | dict; optional)

- color (string; default '#000'):
    设置二维码颜色  默认：'#000'.

- errorLevel (a value equal to: 'L', 'M', 'Q', 'H'; default 'M'):
    设置二维码纠错等级，可选的有'L'、'M'、'Q'、'H'  默认：'M'.

- expires (number; optional):
    设置当前二维码过期时间，单位：秒，到期后二维码状态将会被强制更新为'expired'.

- icon (string; optional):
    用于设置二维码中图片的地址（目前只支持图片地址）.

- iconSize (number; default 40):
    设置二维码中图片的大小  默认：40.

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- refreshClicks (number; default 0):
    监听当前\"点击刷新\"按钮累计点击次数，仅在status为'expired'时有意义.

- size (number; default 160):
    设置二维码像素尺寸  默认：160.

- status (a value equal to: 'active', 'expired', 'loading'; default 'active'):
    设置二维码状态，可选的有'active'、'expired'、'loading'  默认：'active'.

- style (dict; optional)

- type (a value equal to: 'canvas', 'svg'; default 'canvas'):
    设置渲染类型，可选的有'canvas'、'primary'  默认：'canvas'.

- value (string; optional):
    用于设置扫描后的文本."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdQRCode'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, locale=Component.UNDEFINED, value=Component.UNDEFINED, type=Component.UNDEFINED, icon=Component.UNDEFINED, size=Component.UNDEFINED, iconSize=Component.UNDEFINED, color=Component.UNDEFINED, bgColor=Component.UNDEFINED, bordered=Component.UNDEFINED, errorLevel=Component.UNDEFINED, status=Component.UNDEFINED, expires=Component.UNDEFINED, autoSpin=Component.UNDEFINED, refreshClicks=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'autoSpin', 'bgColor', 'bordered', 'className', 'color', 'errorLevel', 'expires', 'icon', 'iconSize', 'key', 'loading_state', 'locale', 'refreshClicks', 'size', 'status', 'style', 'type', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'autoSpin', 'bgColor', 'bordered', 'className', 'color', 'errorLevel', 'expires', 'icon', 'iconSize', 'key', 'loading_state', 'locale', 'refreshClicks', 'size', 'status', 'style', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdQRCode, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSkeleton(Component):
    """An AntdSkeleton component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- active (boolean; default False)

- avatar (dict; default False)

    `avatar` is a boolean | dict with keys:

    - active (boolean; optional)

    - shape (a value equal to: 'circle', 'square'; optional)

    - size (number | a value equal to: 'large', 'small', 'default'; optional)

- className (string | dict; optional)

- debug (boolean; default False)

- excludeProps (list of strings; optional)

- includeProps (list of strings; optional)

- key (string; optional)

- listenPropsMode (a value equal to: 'default', 'exclude', 'include'; default 'default')

- loading (boolean; default False)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- paragraph (dict; default True)

    `paragraph` is a boolean | dict with keys:

    - rows (number; optional)

    - width (number | string | list of number | strings; optional)

- round (boolean; default False)

- style (dict; optional)

- title (dict; default True)

    `title` is a boolean | dict with keys:

    - width (number | string; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSkeleton'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, loading=Component.UNDEFINED, active=Component.UNDEFINED, avatar=Component.UNDEFINED, paragraph=Component.UNDEFINED, title=Component.UNDEFINED, round=Component.UNDEFINED, debug=Component.UNDEFINED, listenPropsMode=Component.UNDEFINED, excludeProps=Component.UNDEFINED, includeProps=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'avatar', 'className', 'debug', 'excludeProps', 'includeProps', 'key', 'listenPropsMode', 'loading', 'loading_state', 'paragraph', 'round', 'style', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'avatar', 'className', 'debug', 'excludeProps', 'includeProps', 'key', 'listenPropsMode', 'loading', 'loading_state', 'paragraph', 'round', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSkeleton, self).__init__(children=children, **args)
